summaryrefslogtreecommitdiff
path: root/indra/newview/llvotree.h
diff options
context:
space:
mode:
authorNyx Linden <nyx@lindenlab.com>2013-08-16 19:31:16 -0400
committerNyx Linden <nyx@lindenlab.com>2013-08-16 19:31:16 -0400
commit5ae117aff6bfbc3c07876146ca270129dd91a047 (patch)
tree462f491cc055aa296b9da0041a322cd9512c045b /indra/newview/llvotree.h
parent8abd6ed6b8c294ec6bfca59929dbcc71cd65c3a3 (diff)
parent32b8d398eca5eaa4ca99aa48839ad64d97954cae (diff)
merge with viewer-release
Diffstat (limited to 'indra/newview/llvotree.h')
-rwxr-xr-xindra/newview/llvotree.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/indra/newview/llvotree.h b/indra/newview/llvotree.h
index 52debc85ab..2ecb0303a1 100755
--- a/indra/newview/llvotree.h
+++ b/indra/newview/llvotree.h
@@ -104,19 +104,16 @@ public:
F32 twist,
F32 droop,
F32 branches,
- F32 alpha);
+ F32 alpha);
- U32 drawBranchPipeline(LLMatrix4& matrix, U16* indicesp, S32 trunk_LOD, S32 stop_level, U16 depth, U16 trunk_depth, F32 scale, F32 twist, F32 droop, F32 branches, F32 alpha);
-
-
- /*virtual*/ BOOL lineSegmentIntersect(const LLVector3& start, const LLVector3& end,
+ /*virtual*/ BOOL lineSegmentIntersect(const LLVector4a& start, const LLVector4a& end,
S32 face = -1, // which face to check, -1 = ALL_SIDES
BOOL pick_transparent = FALSE,
S32* face_hit = NULL, // which face was hit
- LLVector3* intersection = NULL, // return the intersection point
+ LLVector4a* intersection = NULL, // return the intersection point
LLVector2* tex_coord = NULL, // return the texture coordinates of the intersection point
- LLVector3* normal = NULL, // return the surface normal at the intersection point
- LLVector3* bi_normal = NULL // return the surface bi-normal at the intersection point
+ LLVector4a* normal = NULL, // return the surface normal at the intersection point
+ LLVector4a* tangent = NULL // return the surface tangent at the intersection point
);
static S32 sMaxTreeSpecies;